@@ -27,8 +27,7 @@ from typing import TYPE_CHECKING, Any
 
 from googleapiclient.errors import HttpError
 
-from airflow.configuration import conf
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException, conf
 from airflow.providers.google.cloud.hooks.dataflow import (
     DEFAULT_DATAFLOW_LOCATION,
     DataflowHook,
@@ -132,6 +131,7 @@ class DataflowConfiguration:
         Supported only by:
         :class:`~airflow.providers.apache.beam.operators.beam.BeamRunJavaPipelineOperator`.
     :param service_account: Run the job as a specific service account, instead of the default GCE robot.
+    :param max_num_workers: Maximum amount of workers that will be used for Dataflow job execution.
     """
 
     template_fields: Sequence[str] = ("job_name", "location")
@@ -152,6 +152,7 @@ class DataflowConfiguration:
         multiple_jobs: bool | None = None,
         check_if_running: CheckJobRunning = CheckJobRunning.WaitForRun,
         service_account: str | None = None,
+        max_num_workers: int | None = None,
     ) -> None:
         self.job_name = job_name
         self.append_job_name = append_job_name
@@ -166,6 +167,7 @@ class DataflowConfiguration:
         self.multiple_jobs = multiple_jobs
         self.check_if_running = check_if_running
         self.service_account = service_account
+        self.max_num_workers = max_num_workers
 
 
 class DataflowTemplatedJobStartOperator(GoogleCloudBaseOperator):
